# My Library

## Installation

```sh
pip install .

```Usage
from my_library import get

url = 'http://example.com'
get(url, print_response=True, print_text=True)



### 8. نصب کتابخانه

برای آزمایش نصب کتابخانه، دستور زیر را در خط فرمان اجرا کنید:

```sh
pip install .
